Events
======

.. autoclass:: mcpq.events.EventHandler

-----

.. autoclass:: mcpq.events.SingleEventHandler

-----

.. autoclass:: mcpq.events.PlayerJoinEvent
   :inherited-members:

.. autoclass:: mcpq.events.PlayerLeaveEvent
   :inherited-members:

.. autoclass:: mcpq.events.PlayerDeathEvent
   :inherited-members:

.. autoclass:: mcpq.events.ChatEvent
   :inherited-members:

.. autoclass:: mcpq.events.BlockHitEvent
   :inherited-members:

.. autoclass:: mcpq.events.ProjectileHitEvent
   :inherited-members:
